<?php

/*
 * Prepare the PixelPerfect admin screen for uploading mockups.
 *
 * @return
 *  $output for admin screen
 */
function pixelperfect_admin_settings() {
  $output = drupal_get_form('pixelperfect_upload_form');

  $mockups = variable_get('pixelperfect_mockups', '');

  if ((is_array($mockups) && (count($mockups) > 0))) {
    $output .= '<table>';
    $output .= '<thead><tr><td>' . t('Thumbnail') . '</td><td>' . t('File') . '</td><td>' . t('Operations') . '</td></tr></thead>';
    foreach ($mockups as $key => $mockup) {
      $output .= '<tr>';
      $output .= '  <td>' . l('<img width="200" src="' . base_path() . $mockup['mockup'] . '" />', $mockup['mockup'], array('html' => TRUE)) . '</td>';
      $output .= '  <td>' . l($mockup['mockup'], $mockup['mockup']) . '</td>';
      $output .= '  <td>' . l('Delete', 'admin/settings/pixelperfect/delete/' . $key) . '</td>';
      $output .= '</tr>';
    }
    $output .= '</table>';
  }
  else {
    $output .= t("No mockups have been uploaded yet.");
  }

  return $output;
}

/*
 *  Upload form for the admin screen
 *
 * @return
 *  $form
 */
function pixelperfect_upload_form() {
  $form = array();

  $form['#attributes'] = array(
    'enctype' => "multipart/form-data"
  );
  $form['file_upload'] = array(
    '#type' => 'file',
    '#title' => t('Mockup Filename'),
    '#attributes' => array('class' => 'multi', 'accept' => 'png|jpg'),
    '#description' => t('It is strongly recommended that you work off of .png files.'),
    '#value_callback' => 'pixelperfect_file_upload_value',
    '#tree' => FALSE,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Upload file')
  );

  return $form;
}

function pixelperfect_upload_form_submit($form, &$form_state) {
  // Save new file uploads.
  if ($file = file_save_upload('file_upload', array(), file_directory_path() . '/pixelperfect')) {

    $mockups = variable_get('pixelperfect_mockups', array());

    if (!is_array($mockups)) {
      $mockups = array();
    }

    $new = array();
    $new['mockup'] = file_directory_path() . '/pixelperfect/' . $file->filename;

    if ($file->filemime == 'image/jpeg') {
      _pixelperfect_invert_image($file->filepath, 'invert-' . $file->filename, TRUE);
    }
    else {
      _pixelperfect_invert_image($file->filepath, 'invert-' . $file->filename, TRUE, 'png');
    }
    $new['mockup_invert'] = file_directory_path() . '/pixelperfect/invert-' . $file->filename;
    $new['mockup_top'] = $new['mockup_left'] = '0px';

    $mockups[] = $new;
    variable_set('pixelperfect_mockups', $mockups);
    drupal_set_message('You have successfully uploaded the mockup: ' . $file->filename);
  }
}

/*
 * Confirm delete screen for deleting mockups.
 *
 * @param
 *   &$form_state
 *   $mockup_id
 *
 * @return
 *   $form
 */
function pixelperfect_delete_mockup_form(&$form_state, $mockup_id) {
  $form['mockup_id'] = array(
    '#type' => 'hidden',
    '#value' => $mockup_id
  );
  return confirm_form($form, t('Confirm Delete'), 'admin/settings/pixelperfect', 'This will remove the mockup from the site.', 'Delete', 'Cancel');
}

function pixelperfect_delete_mockup_form_submit($form, &$form_state) {

  $mockups = variable_get('pixelperfect_mockups', array());
  $mockup_id = $form_state['values']['mockup_id'];

  file_delete($mockups[$mockup_id]['mockup']);
  file_delete($mockups[$mockup_id]['mockup_invert']);
  unset($mockups[$form_state['values']['mockup_id']]);

  if (count($mockups) == 0) {
    $new_mockups = 0;
  }
  else {
    $new_mockups = array();
    foreach ($mockups as $mockup) {
      $new_mockups[] = $mockup;
    }
  }

  variable_set('pixelperfect_mockups', $new_mockups);
  drupal_set_message('The mockup has been deleted.');
  drupal_goto('admin/settings/pixelperfect');
}


